<?php

namespace Drupal\smartling\ContextApi;

use Exception;

class SmartlingContextAPI {

  const SANDBOX_MODE = 'SANDBOX';
  const PRODUCTION_MODE = 'PRODUCTION';
  const SANDBOX_URL = 'https://sandbox-api.smartling.com/v1';
  const PRODUCTION_URL = 'https://api.smartling.com/v1';

  /**
   * api base url
   *
   * @var string
   */
  protected $_baseUrl = "";

  /**
   *
   * @var string
   */
  protected $_apiKey;

  /**
   *
   * @var string
   */
  protected $_projectId;

  /**
   *
   * @var null | string
   */
  protected $_response = null;

  public function __construct($baseUrl, $apiKey, $projectId, $mode = self::SANDBOX_MODE) {
    $this->_apiKey = $apiKey;
    $this->_projectId = $projectId;
    if ($mode == self::PRODUCTION_MODE) {
      if (!empty($baseUrl)) {
        $this->_baseUrl = $baseUrl;
      }
      else {
        $this->_baseUrl = self::PRODUCTION_URL;
      }
    }
    else {
      $this->_baseUrl = self::SANDBOX_URL;
    }
  }

  /**
   * send request to Smartling Service
   *
   * @param string $uri
   * @param array $requestData
   * @param string $method
   * @return string
   */
  protected function sendRequest($uri, $requestData, $method, $needUploadFile = false, $needUploadContent = false) {
    $connection = new HttpClient($this->_baseUrl . "/" . $uri, 443);

    $data['apiKey'] = $this->_apiKey;
    $data['projectId'] = $this->_projectId;

    $request = array_replace_recursive($data, $requestData);

    $connection->setMethod($method)
        ->setNeedUploadFile($needUploadFile)
        ->setNeedUploadContent($needUploadContent);


    if ($connection->request($request)) {
      return $this->_response = $connection->getContent();
    }
    else {
      return new Exception("Can't connect to server: " . $connection->getError());
    }
  }

  /**
   *
   * @return boolean | string
   */
  public function getCodeStatus() {
    if (!is_null($this->_response)) {
      if ($result = json_decode($this->_response)) {
        return $result->response->code;
      }
    }
    else {
      return false;
    }
  }

  /**
   * upload context to Smartling
   *
   * @param array $data
   * @return string
   */
  public function uploadContext($data) {
    return $this->sendRequest('context/html', $data, HttpClient::REQUEST_TYPE_POST);
  }

  /**
   * Get statistics for context upload
   *
   * @param array $data
   * @return string
   */
  public function getContextStats($data) {
    return $this->sendRequest('context/html', $data, HttpClient::REQUEST_TYPE_GET);
  }

}
