<?php

/**
 * @file
 * SmartlingApiFactory.php.
 */

namespace Drupal\smartling;

use Drupal;
use Drupal\smartling\ContextApi\SmartlingContextAPI;
use Drupal\smartling\Settings\SmartlingSettingsHandler;
use Exception;
use Smartling\AuthApi\AuthTokenProvider;
use Smartling\File\FileApi;
use Smartling\Project\ProjectApi;
use Smartling\Jobs\JobsApi;

/**
 * Class SmartlingApiFactory
 * @package Drupal\smartling
 */
class SmartlingApiFactory {

  /**
   * Returns API object as a service.
   *
   * @param \Drupal\smartling\Settings\SmartlingSettingsHandler $settings
   * @param string $api_type
   * @return \Smartling\BaseApiAbstract
   * @throws \Exception
   * @throws \Smartling\Exceptions\SmartlingApiException
   */
  static function create(SmartlingSettingsHandler $settings, $api_type = 'file') {
    require_once __DIR__ . '/../../../vendor/autoload.php';

    $auth_provider = AuthTokenProvider::create($settings->getUserId(), $settings->getTokenSecret());
    $api = NULL;

    switch ($api_type) {
      case 'file':
        $api = FileApi::create($auth_provider, $settings->getProjectId());

        break;

      case 'project':
        $api = ProjectApi::create($auth_provider, $settings->getProjectId());

        break;

      case 'jobs':
        $api = JobsApi::create($auth_provider, $settings->getProjectId());

        break;

      // TODO: 3.x - for now Smartling API doesn't have Context API so we need
      // to deal with it somehow.. I think we need to add Context API class
      // to Smartling SDK in a future.
      case 'context':
        $api = new SmartlingContextAPI($settings->getApiUrl(), $settings->getKey(), $settings->getProjectId(), SMARTLING_PRODUCTION_MODE);

        break;

      default:
        throw new Exception('Unsupported API has been requested: ' . $api_type);
    }

    return $api;
  }

}
