<?php

use Drupal\smartling\ContextApi\SmartlingContextAPI;
use Drupal\smartling\Settings\SmartlingSettingsHandler;
use Drupal\smartling\SmartlingApiFactory;
use Smartling\File\FileApi;
use Smartling\Jobs\JobsApi;
use Smartling\Project\ProjectApi;

define('SMARTLING_PRODUCTION_MODE', 'PRODUCTION');

/**
 * @file
 * Tests for smartling.
 */

class ApiFactoryTest extends \PHPUnit_Framework_TestCase {

  private $settingsMock;

  /**
   * Test mixture.
   */
  public function setUp() {
    $this->settingsMock = $this->getMock(SmartlingSettingsHandler::class);
  }

  /**
   * Test factory: request unsupported API.
   *
   * @expectedException Exception
   * @expectedExceptionMessage Unsupported API has been requested: unsupportedAPI
   */
  public function testCreateUnsupportedApi() {
    SmartlingApiFactory::create($this->settingsMock, 'unsupportedAPI');
  }

  /**
   * Test factory: request supported APIs.
   *
   * @param array $data
   *
   * @dataProvider testCreateAPIObjectsDataProvider
   */
  public function testCreateAPIObjects(array $data) {
    $apiObject = SmartlingApiFactory::create($this->settingsMock, $data['type']);
    $this->assertInstanceOf($data['class'], $apiObject);
  }

  public function testCreateAPIObjectsDataProvider() {
    return [
      [
        ['type' => 'file', 'class' => FileApi::class],
      ],
      [
        ['type' => 'project', 'class' => ProjectApi::class],
      ],
      [
        ['type' => 'jobs', 'class' => JobsApi::class],
      ],
      [
        ['type' => 'context', 'class' => SmartlingContextAPI::class],
      ],
    ];
  }

}
